#!/bin/bash

POSTINST=`echo $0 | grep -o postinst`

USER_ID=`id -u`
if [ $USER_ID -ne 0 ]
then
	echo "$0 must be run as a root user."
	exit 1
fi


if [ "$POSTINST" != "postinst" ]
then
	#We are not in a package, install executables.
	echo "Installing Striata reader in /usr"
	cp -R usr /
fi

#Detect if we have the xdg tools available.
XDG=`which xdg-open 2> /dev/null`
XDG_MIME=`which xdg-mime 2> /dev/null`
XDG_ICON=`which xdg-icon-resource 2> /dev/null`
XDG_DESKTOP=`which xdg-desktop-menu 2> /dev/null`

if [[ "$XDG" == "" || "$XDG_MIME" == "" || "$XDG_ICON" == "" || "$XDG_DESKTOP" == "" ]]
then
	echo "Freedesktop.org XdgUtils not available:"
	echo "Not registering MIME-types or desktop shortcut."
	echo "To run the reader please execute: striata-reader"
	exit 0
else
	if [ "$POSTINST" != "postinst" ]
	then
		echo "Freedesktop.org tools present: Registering MIME-types and desktop shortcut."
	fi
fi

RESOLUTIONS=" 16 22 24 32 48 72 96 128 192 256 "

#Register application
READER_DIR=/usr/share/striata-reader
ICON_DIR=/usr/share/striata-reader/icons
LIB_DIR=/usr/share/striata-reader/lib
PLUGINS_DIR="$LIB_DIR/plugins"
MIME_NAME="application-x-emc"
MIME_EMD="application-x-emd"
MIME_ICON="striata-emc.png"
APP_ICON="striata-keymail.png"
LEGACY_XML_FILE="$READER_DIR/striata-emc.xml"
LEGACY_XML_EMD="$READER_DIR/striata-emd.xml"
XML_FILE="$READER_DIR/x-emc.xml"
XML_EMD="$READER_DIR/x-emd.xml"
DESKTOP_FILE="$READER_DIR/striata-keymail.desktop"

#Remove possible legacy(incorrect) mime associations.
xdg-mime uninstall $LEGACY_XML_FILE
xdg-mime uninstall $LEGACY_XML_EMD

#Register mime type for striata EMC
xdg-mime install $XML_FILE
xdg-mime install $XML_EMD

#Install icons after mimetype is installed.

chmod 755 $READER_DIR
chmod 755 $ICON_DIR
for i in $RESOLUTIONS
do
	echo "Installing resolution ($i) icons."
	chmod 755 $ICON_DIR/$i
	chmod 644 $ICON_DIR/$i/$MIME_ICON
	chmod 644 $ICON_DIR/$i/$APP_ICON
	xdg-icon-resource install --mode system --size $i --context mimetypes $ICON_DIR/$i/$MIME_ICON $MIME_NAME
	xdg-icon-resource install --mode system --size $i --context mimetypes $ICON_DIR/$i/$MIME_ICON $MIME_EMD
	xdg-icon-resource install --mode system --size $i $ICON_DIR/$i/$APP_ICON
done

xdg-icon-resource forceupdate

# Setup library and plugins permissions
PLUGINS_DIRECTORIES="$PLUGINS_DIR $PLUGINS_DIR/imageformats $PLUGINS_DIR/platforms"
for dir in $PLUGINS_DIRECTORIES
do
	if [ -d $dir ]
	then
		echo "Setting permissions for $dir"
		chmod a+rx $dir
	fi
done

if [ -d $dir ]
then
	find $LIB_DIR -type f | xargs -n1 chmod a+r
fi


#Install keymail decoder in the desktop menu (mandatory for mime type association)
xdg-desktop-menu install $DESKTOP_FILE
xdg-desktop-menu forceupdate


